import { BasicColumn, FormSchema } from '@/components/Table';

export const columns: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 150,
    sorter: true,
  },
  {
    title: '数据库',
    dataIndex: 'database',
    width: 220,
    sorter: true,
  },
  {
    title: '表类型',
    dataIndex: 'tableType',
    width: 220,
    sorter: true,
  },
  {
    title: '创建时间',
    dataIndex: 'creationTime',
    width: 120,
    sorter: true,
  },
  {
    title: '更新时间',
    dataIndex: 'updateTime',
    width: 120,
    sorter: true,
  },
  {
    title: '拥有者',
    dataIndex: 'owner',
    width: 120,
    sorter: true,
  },
];

export const fieldConfiguration: BasicColumn[] = [
  {
    title: '排序',
    dataIndex: 'sort',
    width: 50,
    slots: { customRender: 'sort' },
  },
  {
    title: '字段中文名',
    dataIndex: 'fieldChineseName',
    width: 150,
    edit: true,
    editComponent: 'Input',
  },
  {
    title: '字段英文名',
    dataIndex: 'fieldEnglishName',
    width: 120,
    edit: true,
    editComponent: 'Input',
  },
  {
    title: '字段类型',
    dataIndex: 'tableType',
    width: 120,
    edit: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        {
          label: 'string',
          value: '1',
        },
        {
          label: 'varchar',
          value: '2',
        },
      ],
    },
  },
  {
    title: '字段长度',
    dataIndex: 'fieldType',
    width: 100,
    edit: true,
    editComponent: 'Input',
  },
  {
    title: '字段精度',
    dataIndex: 'fieldAccuracy',
    width: 100,
    edit: true,
  },
  {
    title: '非空',
    dataIndex: 'nonEmpty',
    width: 100,
    editComponent: 'Checkbox',
    slots: { customRender: 'nonEmpty' },
  },
];

export const personSchemaTwo: FormSchema[] = [
  {
    field: 'tableConfiguration',
    slot: 'tableConfiguration',
  },
  {
    field: 'disclosure',
    component: 'RadioGroup',
    label: '分区类型',
    colProps: {
      span: 24,
    },
    componentProps: {
      options: [
        {
          label: '单值分区',
          value: '1',
        },
        {
          label: '范围分区',
          value: '2',
        },
      ],
    },
  },
  {
    field: 'giveAnExample',
    label: '分区健',
    colProps: { lg: 12, md: 12 },
    component: 'Input',
    itemProps: {
      extra: '建议分区键选择日期字段或地区字段',
    },
  },
  {
    field: 'PartitionHealth',
    component: 'Select',
    colProps: {
      span: 3,
    },
    componentProps: {
      options: [
        {
          label: 'String',
          value: '1',
        },
        {
          label: 'varchar',
          value: '2',
        },
      ],
    },
  },
  {
    field: 'partitionKeyDeletion',
    slot: 'delete',
  },
  {
    field: 'partitionHealth',
    label: '分区键',
    colProps: { lg: 9, md: 9 },
    component: 'Input',
    itemProps: {
      extra: '建议分区键选择日期字段或地区字段',
    },
  },
  {
    field: 'partitionHealthTwoSelect',
    component: 'Select',
    colProps: {
      span: 3,
    },
    componentProps: {
      options: [
        {
          label: 'String',
          value: '1',
        },
        {
          label: 'varchar',
          value: '2',
        },
      ],
    },
  },
  {
    field: 'partitionHealthTwoInput',
    colProps: { lg: 3, md: 3 },
    component: 'Input',
  },
  {
    field: 'partitionKeyDeletion',
    slot: 'delete',
  },
  {
    field: 'addBtn',
    slot: 'addBtn',
    colProps: { lg: 24, md: 24 },
  },
];
export const bucketingSchema: FormSchema[] = [
  {
    field: 'tableConfiguration',
    slot: 'tableConfiguration',
    colProps: { lg: 13, md: 13 },
  },
  {
    field: 'bucketButton',
    label: '分桶键',
    colProps: { lg: 13, md: 13 },
    component: 'Input',
    itemProps: {
      extra: '分桶 键尽量选值域均匀、重复率不高的字段',
    },
  },
  {
    field: 'numberOfBucketsDivided',
    label: '分桶个数',
    colProps: { lg: 13, md: 13 },
    component: 'Input',
  },
];

export const personSchema: FormSchema[] = [
  {
    field: 'tableConfiguration',
    slot: 'tableConfiguration',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'disclosure',
    component: 'RadioGroup',
    label: '表所有权',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        {
          label: '内表',
          value: '1',
        },
        {
          label: '外表',
          value: '2',
        },
      ],
    },
  },

  {
    field: 'dataConnection ',
    label: '表类型',
    colProps: { lg: 11, md: 11 },
    component: 'Select',
    required: true,
    componentProps: {
      options: [{ label: 'orc', value: '1' }],
    },
  },

  {
    field: 'classPath',
    label: '表中文名',
    colProps: { lg: 11, md: 11 },
    component: 'Input',
    required: true,
  },

  {
    field: 'ruleDescription',
    label: '表英文名',
    colProps: { lg: 11, md: 11 },
    component: 'Input',
  },
  {
    field: 'operator',
    label: '库名',
    colProps: { lg: 11, md: 11 },
    component: 'Input',
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'classPath',
    label: '表中文名',
    colProps: { lg: 22, md: 22 },
    component: 'Input',
  },

  {
    field: 'ruleDescription',
    label: '表英文名',
    colProps: { lg: 22, md: 22 },
    component: 'Input',
    required: true,
  },
  {
    field: 'ruleHandling',
    label: '字段类型',
    colProps: { lg: 22, md: 22 },
    component: 'Select',
    componentProps: {
      options: [
        { label: 'String', value: '1' },
        { label: 'varchar', value: '2' },
      ],
    },
  },
  {
    field: 'ruleDescription',
    label: 'not null',
    colProps: { lg: 22, md: 22 },
    component: 'Checkbox',
  },
];
export const MoveFormSchema: any[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];
export const addFileFormSchema: any[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'name',
    component: 'Input',
    label: '名称',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
];
